package org.litesoft.template;

// Copyright Status:
//
// All Software available from LiteSoft.org (including this file) is
// hereby released into the public domain.
//
// It is free!  As in, you may use it freely in both commercial and
// non-commercial applications, bundle it with your software
// distribution, include it on a CD-ROM, list the source code in a book,
// mirror the documentation at your own web site, or use it in any other
// way you see fit.
//
// NO Warranty!
//
// All software is provided "as is".
//
// There is ABSOLUTELY NO WARRANTY OF ANY KIND: not for the design, fitness
// (for a particular purpose), level of errors (or lack thereof), or
// applicability of this software.  The entire risk as to the quality
// and performance of this software is with you.  Should this software
// prove defective, you assume the cost of all necessary servicing, repair
// or correction.
//
// In no event unless required by applicable law or agreed to in writing
// will any party who created or may modify and/or redistribute this
// software, be liable to you for damages, including any general,
// special, incidental or consequential damages arising out of the use or
// inability to use this software (including but not limited to loss of
// data or data being rendered inaccurate or losses sustained by you or
// third parties or a failure of this software to operate with any
// other programs), even if such holder or other party has been advised
// of the possibility of such damages.
//
// NOTE: Should you discover a bug, have a recogmendation for a change, wish
// to submit modifications, or wish to add new classes/functionality,
// please email them to:
//
//        changes@litesoft.org
//

/**
 * This class provides both a <i>NULL Object</i> implementation and an
 * interface that provides the substitution text (or lines) for a
 * Substitution Field.<p>
 *
 * This class is normally overriden to provide for actual substitution
 * text (or lines).  The two methods are either individually overriden,
 * or both overriden IF it makes sense that this field can be
 * used in "both" ways.<p>
 *
 * If this class is used directly, then it behaves like a <i>NULL Object</i>,
 * in that if behaves in a maner that is reasonable, but produces Nothing!
 *
 * Exceptions: All problems caught when the parameter(s) are checked (as
 * indicated/implied in the @param tags) will generate an IllegalArgumentException,
 * and means the API user has a problem.  If a NullPointerException (or some
 * others, like: ClassCastException or ArrayIndexOutOfBoundsException) is thrown,
 * it means the API developer has a problem.  Any Exception that is explicitly
 * thrown in the API, but unrelated to a parameter, will be listed in the throws
 * clause (and hopefully in the tag @throws).  These may (but probably won't) be
 * checked Exceptions.
 *
 * @author  George Smith
 * @version 1.2 02/07/02 Exception Policy, Use of IllegalArgument class.
 * @version 1.1 11/12/01 JavaDoc'd
 * @version 1.0 11/07/01
 */
public class TemplateSubstitutionFieldControl
{
    private static final TemplateSubstitutionFieldControl INSTANCE = new TemplateSubstitutionFieldControl();
    /**
     * An Empty String array, to be used as an immutable return value to the
     * getMultiLineSubstitution() method.
     */
    protected static final String[] NO_LINES = new String[0];

    /**
     * Constructor that instantiates this as a <i>NULL Object</i>,
     */
    public TemplateSubstitutionFieldControl()
    {
    }

    /**
     * Create/return an instance of a TemplateSubstitutionFieldControl that
     * has the same FieldID, but can handle the passed in Parameters.<p>
     *
     * @param   pParams     The Parameters that modify <i>this</i> (by creating
     *                      a new instance) to probably return different
     *                      substitution Strings.(!null).<p>
     *
     * @return a TemplateSubstitutionFieldControl for <i>this</i>'s FieldID
     *          <b>and</b> the passed in Parameters.
     */
    public TemplateSubstitutionFieldControl getInstance( String pParams )
    {
        return INSTANCE;
    }

    /**
     * Return the String to substitute for this field.<p>
     */
    public String getStringSubstitution()
    {
        return "";
    }

    /**
     * Return the lines (as a String Array) that should be substituted for
     * a field that IS a <b>line</b>.
     */
    public String[] getMultiLineSubstitution()
    {
        return NO_LINES;
    }
}
